@@ -1,33 +1,4 @@
-# coding: utf-8
-# /*##########################################################################
-#
-# Copyright (c) 2016-2017 European Synchrotron Radiation Facility
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-# ###########################################################################*/
-
-
-__authors__ = ["H. Payno"]
-__license__ = "MIT"
-__date__ = "03/11/2020"
-
+from __future__ import annotations
 
 import fnmatch
 from collections import OrderedDict
@@ -42,7 +13,7 @@ from processview.core.manager import ProcessManager as _ProcessManager
 from processview.core.sorting import SortType, tooltips
 from processview.core.superviseprocess import SuperviseProcess
 from processview.gui.DropDownWidget import DropDownWidget
-from processview.gui import icons as icons
+from silx.gui import icons
 from processview.gui.messagebox import MessageBox
 from processview.utils import docstring
 
@@ -83,8 +54,8 @@ class ObservationTable(qt.QTableView):
         self.dataset_menu = qt.QMenu()
         self._copyAction = qt.QAction("copy")
         self.dataset_menu.addAction(self._copyAction)
-        self._clearAction = qt.QAction("clear")
-        self.dataset_menu.addAction(self._clearAction)
+        self._removeAction = qt.QAction("remove")
+        self.dataset_menu.addAction(self._removeAction)
 
         # QMenu for cell from on dataset and one process
         self.menu_dataset_vs_process = qt.QMenu()
@@ -94,14 +65,14 @@ class ObservationTable(qt.QTableView):
         self.menu_dataset_vs_process.addAction(self._cancelAction)
         self._infoAction = qt.QAction("info")
         self.menu_dataset_vs_process.addAction(self._infoAction)
-        self.menu_dataset_vs_process.addAction(self._clearAction)
+        self.menu_dataset_vs_process.addAction(self._removeAction)
 
         self._target = (None, None)
         # register target of the last menu (process, DatasetIdentifier)
 
         # connect signal / slot
         self._copyAction.triggered.connect(self._requestDatasetIdCopy)
-        self._clearAction.triggered.connect(self._requestClearDataset)
+        self._removeAction.triggered.connect(self._requestRemoveDataset)
         self._reprocessAction.triggered.connect(self._requestReprocessing)
         self._infoAction.triggered.connect(self._requestInfo)
         self._cancelAction.triggered.connect(self._requestCancelProcessing)
@@ -163,7 +134,7 @@ class ObservationTable(qt.QTableView):
             clipboard = qt.QGuiApplication.clipboard()
             clipboard.setText(dataset.to_str())
 
-    def _requestClearDataset(self, *args, **kwargs):
+    def _requestRemoveDataset(self, *args, **kwargs):
         def get_dataset_at(row: int):
             datasets = self.model()._sorted_datasets
             return datasets.get(
@@ -244,6 +215,7 @@ class ProcessManagerWidget(qt.QWidget):
         self._optionsWidget._orderingWidget.sigSortTypeChanged.connect(
             self.observationTable.model()._setSorting
         )
+        self._manager.sigProcessRenamed.connect(self._renameProcess)
         # update to fit existing processes / datasets
         self._updateProcesses()
         self._updateDatasetStates()
@@ -254,6 +226,11 @@ class ProcessManagerWidget(qt.QWidget):
     def _updateProcesses(self):
         self.observationTable.model().setProcesses(self._manager.get_processes())
 
+    def _renameProcess(self, process: SuperviseProcess):
+        self.observationTable.model().headerDataChanged.emit(
+            qt.Qt.Horizontal, 0, len(self._manager.get_processes())
+        )
+
     def _filterUpdated(self):
         self.observationTable.model().process_patterns = (
             self._dropDownOptionsWidget.getProcessPatterns()
@@ -506,9 +483,9 @@ class _FilterWidget(qt.QWidget):
         font.setPixelSize(font_size)
         self.setFont(font)
 
-        icon = icons.getQIcon("magnifying_glass")
+        icon = icons.getQPixmap("processview:gui/icons/magnifying_glass")
         self._researchLabelIcon = qt.QLabel("", parent=self)
-        self._researchLabelIcon.setPixmap(icon.pixmap(icon_size, state=qt.QIcon.On))
+        self._researchLabelIcon.setPixmap(icon)
         self.layout().addWidget(qt.QLabel(name, self), 0, 1, 1, 1)
         self.layout().addWidget(self._researchLabelIcon, 0, 2, 1, 1)
 
@@ -628,6 +605,9 @@ class ProcessManager(qt.QObject):
     sigProcessUnregistered = qt.Signal()
     """Signal emitted when a process is unregistered"""
 
+    sigProcessRenamed = qt.Signal(SuperviseProcess)
+    """Emit when the process is renamed"""
+
     def __init__(self):
         qt.QObject.__init__(self)
         self.manager = _ProcessManager()
@@ -637,6 +617,7 @@ class ProcessManager(qt.QObject):
         self.manager.add_update_callback(self.updated)
         self.manager.add_new_process_callback(self.processAdded)
         self.manager.add_process_removed_callback(self.processRemoved)
+        self.manager.add_process_name_changed_callback(self.processRenamed)
 
     def updated(self):
         self.sigUpdated.emit()
@@ -647,8 +628,8 @@ class ProcessManager(qt.QObject):
     def processRemoved(self):
         self.sigProcessUnregistered.emit()
 
-    def processNameChanged(self, process):
-        self.sigProcessNameChanged.emit(process)
+    def processRenamed(self, process):
+        self.sigProcessRenamed.emit(process)
 
     def destroyed(self, object_):
         self.manager.remove_update_callback(self.updated)
